<?php

/**
 * GepCtrlencasoliLogic.
 *
 * @package Logic
 * @author  erikasouza
 */
class GepCtrlencasoliLogic{


    private $_GepCtrlencasoliEntity;


    /**
     * Construtor da classe.
     */
    public function __construct(){
        $this->_GepCtrlencasoliEntity = new GepCtrlencasoliEntity();
    }


    /**  ok
     * Insere um novo registro de controle de um encaminhamento.
     *
     * @param integer $solicitacao  Numero da solicitacao.
     * @param integer $tiposoli     Numero do tipo da solicitacao.
     * @param integer $situacao     Numero da situacao atual.
     * @param integer $tiposoli_ant Numero do tipo de solicitacao anterior.
     * @param integer $situacao_ant Numero da Situacao anterior.
     * @param integer $nrorg        Numero da Organizacao.
     * @param date    $date         Data da insercao.
     * @param integer $operador     Codigo do operador que fez a insercao.
     *
     * @return boolean
     */
    public function insereControleSoli(
        $solicitacao, $tiposoli, $situacao,
        $tiposoli_ant, $situacao_ant,
        $nrorg, $date, $operador
    ){
        $codigo = $this->_GepCtrlencasoliEntity->novoCodigoGepCtrlencasoli($nrorg);
        $insere = $this->_GepCtrlencasoliEntity->insereControleSoli(
            $codigo, $solicitacao, $tiposoli, $situacao,
            $tiposoli_ant, $situacao_ant,
            $nrorg, $date, $operador
        );
        return $insere;
    }


    /**
     * Gera novo c?digo para o controle de encaminhamento.
     *
     * @param integer $nrorg  N?mero da organiza??o.
     * @param integer $filial C?digo da filial.
     *
     * @return Ambigous <number, number>
     */
    public static function novoCodigoGepCtrlencasoli($nrorg, $filial){
        $codigo = GepCtrlencasoliEntity::novoCodigoGepCtrlencasoli($nrorg, $filial);
        return $codigo;
    }


    /**   ok
     * Retorna dados do ultimo encaminhamento de uma determinada solicitacao.
     *
     * @param integer $nrorg       Numero da Organicao.
     * @param integer $solicitacao Numero da solicitacao.
     *
     * @return Ambigous <boolean, mixed, NULL>
     */
    public function retornaDadosControle($nrorg, $solicitacao){
        try {
            $dados = $this->_GepCtrlencasoliEntity->retornaDadosControle($nrorg, $solicitacao);
            return $dados;
        } catch (Exception $e) {
            switch ($e->getCode()){
            case GepCtrlencasoliEntity::SEM_CTRL:
                return GepCtrlencasoliEntity::SEM_CTRL;
            default:
                tk_message('Erro desconhecido: '.$e->getMessage(), 'warning');
                return false;
            }
        }

    }


    /**    ok
     * Exclui um resgistro de controle da solicitacao.
     *
     * @param integer $nrorg       Numero da Organizacao.
     * @param integer $solicitacao Numero da solicitacao.
     *
     * @return boolean
     */
    public function excluiControle($nrorg, $solicitacao){
        $dados = $this->_GepCtrlencasoliEntity->excluiControle($nrorg, $solicitacao);
        return $dados;
    }


	/**    ok
     * Exclui todos os registros de controle da solicitacao.
     *
     * @param integer $nrorg       Numero da Organizacao.
     * @param integer $solicitacao Numero da solicitacao.
     *
     * @return boolean
     */
    public function excluiControles($nrorg, $solicitacao){
        $dados = $this->_GepCtrlencasoliEntity->excluiControles($nrorg, $solicitacao);
        return $dados;
    }


}